Communication channels — Invenio 3.1.2 documentation

# Communication channels

## Chatrooms

Most day-to-day communication is happening in our chatrooms:

- Public chatroom (for everyone)

- Developer chatroom (for members of inveniosoftware GitHub organisation).

If you want to join the developer chatroom, just ask for an invite on the public chatroom.

## GitHub

Most of the developer communication is happening on GitHub. You are stroungly encouraged to join https://github.com/orgs/inveniosoftware/teams/developers team and watch notifications from various https://github.com/inveniosoftware/ organisation repositories of interest.

## Meetings

### Invenio Developer Forum

Monday afternoons at 16:00 CET/CEST time we meet physically at CERN and virtually over videoconference to discuss interesting development topics.

You can join our Monday forums from anywhere via videoconference. Here the steps:

- View the agenda (ical feed).

- Install the videoconferencing client Vidyo.

- Join our virtual room.

### Invenio User Group Workshop

We meet among Invenio users and developers from around the world at a yearly Invenio User Group Workshop. The workshop consists of a series of presentations, tutorials, practical exercises, and discussions on topics related to Invenio digital library management and development. We exchange knowledge and experiences and drive forward the forthcoming developments of the Invenio platform.

See list of upcoming and past workshops.

### Other meetings

In addition to above meetings where everyone can join, the following meetings exists:

- Quarterly project coordination meeting with the Invenio project coordinators and architects that help steer the project prioritizes and goals.

- Weekly architecture meeting.

## Project website

Our project website, http://inveniosoftware.org, is used to show case Invenio.

## Email

You can get in touch with the Invenio management team on info@inveniosoftware.org.

In particular use above email address to report security related issues privately to us, so we can distribute a security patch before potential attackers look at the issue.

## Twitter

The official Twitter account for Invenio software is used mostly for announcing new releases and talks at conferences:

- https://twitter.com/inveniosoftware

## Mailing lists

The mailing lists are currently not very active and are primiarly listed here for historical reasons.

- `project-invenio-announce@cern.ch`: Read-only moderated mailing list to announce new Invenio releases and other major news concerning the project. subscribe to announce, archive

- `project-invenio-general@cern.ch`: Originally used for discussion among users and administrators of Invenio instances. The mailing list has mostly been replaced by our public chatroom. subscribe to general, new general archive, old general archive

- `project-invenio-devel@cern.ch`: Originally used for discussion among Invenio developers. The mailing list has mostly been replaced by our developer chatroom. subscribe to devel, new devel archive, old devel archive

Note that all the mailing lists are also archived (as of the 20th of July, 2011) on The Mail Archive.